==> web-8.0.1.tgz: package/lib/modal/index.js <==
import * as React from "react";
import * as ReactDom from "react-dom";
import { Animate } from "../animate/index";
import { SvgIcon } from "../my-icon/index";
import { Button } from "../button/index";
export default class Modal extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.wrap = document.getElementById("wrap-modal");
        this.modalDom = React.createRef();
        this.state = {
            pointX: 0,
            pointY: 0,
            preShow: this.props.show,
            init: false
        };
        this.headMouseDown = (e) => {
            const modalDom = (this.modalDom.current);
            const { pointY, pointX } = this.state;
            const diffPointX = e.clientX - pointX;
            const diffPointY = e.clientY - pointY;
            modalDom.onmousemove = (originE) => {
                this.setState({
                    pointX: (originE.clientX - diffPointX),
                    pointY: (originE.clientY - diffPointY),
                });
            };
        };
        this.close = () => {
            const { toggleFn, field } = this.props;
            toggleFn(field, false);
        };
        this.sureFn = () => {
            const { sureFn, field } = this.props;
            sureFn(field);
        };
        this.headMouseUp = () => {
            (this.modalDom.current).onmousemove = null;
        };
    }
    static getDerivedStateFromProps(nextProps, preState) {
        if (nextProps.show !== preState.preShow) {
            return {
                init: true
            };
        }
        else {
            return null;
        }
    }
    getModalFoot() {
        const { sureFn, customFootFn } = this.props;
        const content = sureFn ? (React.createElement(React.Fragment, null,
            React.createElement(Button, { handle: this.sureFn }, "\u786E\u5B9A"),
            React.createElement(Button, { styleType: "line-btn", handle: this.close }, "\u5173\u95ED"))) : customFootFn ? customFootFn() : undefined;
        return (React.createElement("div", { className: "m-Mfooter" }, content));
    }
    getModal() {
        const { children, wrap, tit, show, className, width } = this.props;
        const { pointX, pointY } = this.state;
        const widthObj = width ? { width: width } : undefined;
        const styleObj = { transform: `translate(${pointX}px, ${pointY}px)`, };
        const container = wrap ? wrap : this.wrap;
        const component = (React.createElement(Animate, { runMount: true, className: `g-modal ${className}`, animation: show ? "bounceDownIn" : "bounceDownOut", duration: 350 },
            React.createElement("div", { style: { height: "100%", }, ref: this.modalDom, onMouseUp: this.headMouseUp },
                React.createElement("div", { className: "m-Mwrap" },
                    React.createElement("div", { className: "m-Mask" }),
                    React.createElement("div", { className: "m-Modal", style: styleObj },
                        React.createElement("div", { className: "m-Mtit", onMouseDown: this.headMouseDown },
                            React.createElement("span", { className: "tit-name" }, tit),
                            React.createElement("span", { className: "m-Mclose", onClick: this.close },
                                React.createElement(SvgIcon, { className: "close" }))),
                        React.createElement("div", { className: "m-Mbody", style: widthObj }, children),
                        this.getModalFoot())))));
        return ReactDom.createPortal(component, container);
    }
    render() {
        const { init } = this.state;
        return init ? this.getModal() : React.createElement(React.Fragment, null);
    }
}

==> web-8.0.2.tgz: package/lib/modal/index.js <==
import * as React from "react";
import * as ReactDom from "react-dom";
import { Animate } from "../animate/index";
import { SvgIcon } from "../my-icon/index";
import { Button } from "../button/index";
export default class Modal extends React.PureComponent {
    constructor(props) {
        super(props);
        this.modalDom = React.createRef();
        this.state = {
            pointX: 0,
            pointY: 0,
            preShow: this.props.show,
            init: false
        };
        this.headMouseDown = (e) => {
            const modalDom = (this.modalDom.current);
            const { pointY, pointX } = this.state;
            const diffPointX = e.clientX - pointX;
            const diffPointY = e.clientY - pointY;
            modalDom.onmousemove = (originE) => {
                this.setState({
                    pointX: (originE.clientX - diffPointX),
                    pointY: (originE.clientY - diffPointY),
                });
            };
        };
        this.close = () => {
            const { toggleFn, field } = this.props;
            toggleFn(field, false);
        };
        this.sureFn = () => {
            const { sureFn, field } = this.props;
            sureFn(field);
        };
        this.headMouseUp = () => {
            (this.modalDom.current).onmousemove = null;
        };
        const dom = document.getElementById("inner-wrap-modal");
        if (!dom) {
            throw new Error("不存在Modal组件的容器，请生成id为 inner-wrap-modal的div");
        }
        this.wrap = dom;
    }
    static getDerivedStateFromProps(nextProps, preState) {
        if (nextProps.show !== preState.preShow) {
            return {
                init: true
            };
        }
        else {
            return null;
        }
    }
    getModalFoot() {
        const { sureFn, customFootFn } = this.props;
        const content = sureFn ? (React.createElement(React.Fragment, null,
            React.createElement(Button, { handle: this.sureFn }, "\u786E\u5B9A"),
            React.createElement(Button, { styleType: "line-btn", handle: this.close }, "\u5173\u95ED"))) : customFootFn ? customFootFn() : undefined;
        return content ? (React.createElement("div", { className: "m-Mfooter" }, content)) : undefined;
    }
    getModal() {
        const { children, wrap, tit, show, className, width } = this.props;
        const { pointX, pointY } = this.state;
        const widthObj = width ? { width: width } : undefined;
        const styleObj = { transform: `translate(${pointX}px, ${pointY}px)`, };
        const container = wrap ? wrap : this.wrap;
        const component = (React.createElement(Animate, { runMount: true, className: `g-modal ${className}`, animation: show ? "bounceDownIn" : "bounceDownOut", duration: 350 },
            React.createElement("div", { style: { height: "100%", }, ref: this.modalDom, onMouseUp: this.headMouseUp },
                React.createElement("div", { className: "m-Mwrap" },
                    React.createElement("div", { className: "m-Mask" }),
                    React.createElement("div", { className: "m-Modal", style: styleObj },
                        React.createElement("div", { className: "m-Mtit", onMouseDown: this.headMouseDown },
                            React.createElement("span", { className: "tit-name" }, tit),
                            React.createElement("span", { className: "m-Mclose", onClick: this.close },
                                React.createElement(SvgIcon, { className: "close", size: "middle" }))),
                        React.createElement("div", { className: "m-Mbody", style: widthObj }, children),
                        this.getModalFoot())))));
        return ReactDom.createPortal(component, container);
    }
    render() {
        const { init } = this.state;
        return init ? this.getModal() : React.createElement(React.Fragment, null);
    }
}
